aboutsummaryrefslogtreecommitdiff
path: root/src/or/or.h
diff options
context:
space:
mode:
authorNick Mathewson <nickm@torproject.org>2008-12-18 16:11:24 +0000
committerNick Mathewson <nickm@torproject.org>2008-12-18 16:11:24 +0000
commit122170c1d3333185bacf361c523c8e19f0a5e8ba (patch)
tree89abcc91294222de3353c64d0e00f98618e9f55e /src/or/or.h
parent6c6b0283cbc24f2d3d3bb7139e1cbeb5a35cfedd (diff)
downloadtor-122170c1d3333185bacf361c523c8e19f0a5e8ba.tar.gz
tor-122170c1d3333185bacf361c523c8e19f0a5e8ba.zip
Downlgrade tweak, and answer lots of XXX021s. No actual code fixes in this patch.
svn:r17686
Diffstat (limited to 'src/or/or.h')
-rw-r--r--src/or/or.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/or/or.h b/src/or/or.h
index 0e79b21430..b766083f44 100644
--- a/src/or/or.h
+++ b/src/or/or.h
@@ -1342,7 +1342,7 @@ typedef struct signed_descriptor_t {
#ifdef TRACK_SERVED_TIME
/** The last time we served anybody this descriptor. Used for internal
* testing to see whether we're holding on to descriptors too long. */
- time_t last_served_at; /*XXXX021 remove if not useful. */
+ time_t last_served_at; /*XXXX remove if not useful. */
#endif
/* If true, we do not ever try to save this object in the cache. */
unsigned int do_not_cache : 1;
@@ -4290,11 +4290,11 @@ smartlist_t *router_get_trusted_dir_servers(void);
*
* Passed to router_pick_directory_server (et al)
*
* [XXXX021 NOTE: This option is only implemented for pick_trusteddirserver,
* not pick_directory_server. If we make it work on pick_directory_server
* too, we could conservatively make it only prevent multiple fetches to
* the same authority, or we could aggressively make it prevent multiple
- * fetches to _any_ directory server.]
+ * fetches to _any_ single directory server.]
*/
#define PDS_NO_EXISTING_SERVERDESC_FETCH (1<<3)
#define _PDS_PREFER_TUNNELED_DIR_CONNS (1<<16)
@@ -4334,9 +4334,9 @@ typedef enum {
CRN_NEED_CAPACITY = 1<<1,
CRN_NEED_GUARD = 1<<2,
CRN_ALLOW_INVALID = 1<<3,
/* XXXX021 not used, apparently. */
CRN_STRICT_PREFERRED = 1<<4,
/* XXXX021 not used, apparently. */
CRN_WEIGHT_AS_EXIT = 1<<5
} router_crn_flags_t;
@@ -4290,11 +4290,11 @@ smartlist_t *router_get_trusted_dir_servers(void);
* Passed to router_pick_directory_server (et al)
*
- * [XXXX021 NOTE: This option is only implemented for pick_trusteddirserver,
+ * [XXXX NOTE: This option is only implemented for pick_trusteddirserver,
* not pick_directory_server. If we make it work on pick_directory_server
* too, we could conservatively make it only prevent multiple fetches to
@@ -4334,9 +4334,9 @@ typedef enum {
CRN_NEED_GUARD = 1<<2,
CRN_ALLOW_INVALID = 1<<3,
- /* XXXX021 not used, apparently. */
+ /* XXXX not used, apparently. */
CRN_STRICT_PREFERRED = 1<<4,
@@ -4334,9 +4334,9 @@ typedef enum {
CRN_STRICT_PREFERRED = 1<<4,
- /* XXXX021 not used, apparently. */
+ /* XXXX not used, apparently. */
CRN_WEIGHT_AS_EXIT = 1<<5
} router_crn_flags_t;